[Python-modules-commits] [authres] 01/03: Imported Upstream version 1.0.1

Scott Kitterman kitterman at moszumanska.debian.org
Fri Aug 4 20:37:45 UTC 2017


This is an automated email from the git hooks/post-receive script.

kitterman pushed a commit to branch debian/master
in repository authres.

commit a72237ef5a31116797f1b55ef0e89b8a263c1718
Author: Scott Kitterman <scott at kitterman.com>
Date:   Fri Aug 4 15:24:41 2017 -0400

    Imported Upstream version 1.0.1
---
 CHANGES             |  3 +++
 PKG-INFO            |  2 +-
 README              |  5 +++--
 authres/__init__.py |  2 +-
 authres/arc.py      | 30 ++++++++++++++++++------------
 authres/tests       |  4 ++--
 setup.py            |  2 +-
 7 files changed, 29 insertions(+), 19 deletions(-)

diff --git a/CHANGES b/CHANGES
index 1819a29..bca2ead 100644
--- a/CHANGES
+++ b/CHANGES
@@ -4,6 +4,9 @@
 #   ! = Changed something significant, or removed a feature
 #   * = Fixed a bug, or made a minor improvement
 
+--- 1.0.1 (2017-08-04)
+  + Extended experimental support for ARC results
+
 --- 1.0.0 (2017-07-14)
   + Added initial experimental support for ARC results
   + Swith to sematic versioning scheme and only set version in setup.py and
diff --git a/PKG-INFO b/PKG-INFO
index 73e1b1d..7909286 100644
--- a/PKG-INFO
+++ b/PKG-INFO
@@ -1,6 +1,6 @@
 Metadata-Version: 1.1
 Name: authres
-Version: 1.0.0
+Version: 1.0.1
 Summary: authres - Authentication Results Header Module
 Home-page: https://launchpad.net/authentication-results-python
 Author: Julian Mehnle, Scott Kitterman
diff --git a/README b/README
index 6805a0c..31819ce 100644
--- a/README
+++ b/README
@@ -9,11 +9,12 @@ RFC 5617 DKIM/ADSP
 RFC 6008 DKIM signature identification (header.b)
 RFC 6212 Vouch By Reference (VBR)
 RFC 6577 Sender Policy Framework (SPF)
-draft-kucherawy-dmarc-base DMARC
 RFC 7281 Authentication-Results Registration for S/MIME
 RFC 7293, The Require-Recipient-Valid-Since Header Field
     and SMTP Service Extension, header field types
-
+RFC 7489 Domain-based Message Authentication, Reporting, and Conformance
+    (DMARC)
+draft-ietf-dmarc-arc-protocol-08 (experimental)
 
 RFC 7410, A Property Types Registry for the Authentication-Results Header
 Field, added the possibility for new ptypes to be created, but so far none
diff --git a/authres/__init__.py b/authres/__init__.py
index 4513ed5..40bb460 100644
--- a/authres/__init__.py
+++ b/authres/__init__.py
@@ -94,7 +94,7 @@ MODULE = 'authres'
 
 __author__  = 'Julian Mehnle, Scott Kitterman'
 __email__   = 'julian at mehnle.net'
-__version__ = '1.0.0'
+__version__ = '1.0.1'
 
 import authres.core
 
diff --git a/authres/tests b/authres/tests
index f953bea..afa824d 100644
--- a/authres/tests
+++ b/authres/tests
@@ -529,10 +529,10 @@ RFC 6212 A.1
 >>> import authres
 >>> import authres.arc
 >>> arc_pass = authres.arc.ARCAuthenticationResult(result = 'pass',
-... header_d = 'example.net')
+... header_ams_d = 'example.net', header_ams_s='valimail2016', header_as_d="example.com", header_as_s="valimail2017")
 >>> str(authres.AuthenticationResultsHeader(authserv_id = 'example.com',
 ... results = [arc_pass]))
-'Authentication-Results: example.com; arc=pass header.d=example.net'
+'Authentication-Results: example.com; arc=pass header.ams-d=example.net header.ams-s=valimail2016 header.as-d=example.com header.as-s=valimail2017'
 
 # Parsing IP6 address.
 >>> arobj = authres_context.parse('Authentication-Results: mail.bmsi.com; iprev=pass policy.iprev="2001:748:100:40::2:2" (mout0.freenet.de); spf=none smtp.mailfrom=markuslaudi at freenet.de')
diff --git a/setup.py b/setup.py
index 8119549..a93e87c 100755
--- a/setup.py
+++ b/setup.py
@@ -16,7 +16,7 @@
 from distutils.core import setup
 
 setup(name='authres',
-      version='1.0.0',
+      version='1.0.1',
       description='authres - Authentication Results Header Module',
       author='Julian Mehnle, Scott Kitterman',
       author_email='julian at mehnle.net',

diff --git a/authres/arc.py b/authres/arc.py
index 6ea90f0..4acc54b 100644
--- a/authres/arc.py
+++ b/authres/arc.py
@@ -17,7 +17,7 @@
 
 """
 authres extension module for the Authenticated Recieved Chain (ARC)
-(draft-ietf-dmarc-arc-protocol-05) authentication method.
+(draft-ietf-dmarc-arc-protocol-08) authentication method.
 """
 
 #MODULE = 'authres'
@@ -30,7 +30,7 @@ from authres.core import make_result_class_properties
 
 class ARCAuthenticationResult(authres.core.AuthenticationResult):
     """
     ARC (draft-ietf-dmarc-arc-protocol-05) result clause of an
     ``Authentication-Results`` header
     Note: Still under development API subject to change."""
 
@@ -40,23 +40,29 @@ class ARCAuthenticationResult(authres.core.AuthenticationResult):
         result               = None,  result_comment               = None,
         reason               = None,  reason_comment               = None,
         properties = None,
-        header_d             = None,  header_d_comment             = None,
+        header_ams_d                = None,  header_ams_d_comment                = None,
+        header_ams_s                = None,  header_ams_s_comment                = None,
+        header_as_d                 = None,  header_as_d_comment                 = None,
+        header_as_s                 = None,  header_as_s_comment                 = None,
     ):
         authres.core.AuthenticationResult.__init__(self, self.METHOD, version,
             result, result_comment, reason, reason_comment, properties)
-        if header_d:                     self.header_d                     = header_d
-        if header_d_comment:             self.header_d_comment             = header_d_comment
+        if header_ams_d:                        self.header_ams_d                    = header_ams_d
+        if header_ams_d_comment:                self.header_ams_d_comment            = header_ams_d_comment
+        if header_ams_s:                        self.header_ams_s                    = header_ams_s
+        if header_ams_s_comment:                self.header_ams_s_comment            = header_ams_s_comment
+        if header_as_d:                         self.header_as_d                     = header_as_d
+        if header_as_d_comment:                 self.header_as_d_comment             = header_as_d_comment
+        if header_as_s:                         self.header_as_s                     = header_as_s
+        if header_as_s_comment:                 self.header_as_s_comment             = header_as_s_comment
 
-    header_d,             header_d_comment             = make_result_class_properties('header', 'd')
-
-    def match_signature(self, signature_d):
-        """Match authentication result against a ARC signature by ``header.d``."""
-
-        return self.header_d == signature_d
+    header_ams_d,             header_ams_d_comment             = make_result_class_properties('header', 'ams-d')
+    header_ams_s,             header_ams_s_comment             = make_result_class_properties('header', 'ams-s')
+    header_as_d,              header_ams_d_comment             = make_result_class_properties('header', 'as-d')
+    header_as_s,              header_ams_s_comment             = make_result_class_properties('header', 'as-s')
 
 RESULT_CLASSES = [
     ARCAuthenticationResult
 ]
 
 # vim:sw=4 sts=4
-    
@@ -30,7 +30,7 @@ from authres.core import make_result_class_properties
 class ARCAuthenticationResult(authres.core.AuthenticationResult):
     """
-    ARC (draft-ietf-dmarc-arc-protocol-05) result clause of an
+    ARC (draft-ietf-dmarc-arc-protocol-08) result clause of an
     ``Authentication-Results`` header
     Note: Still under development API subject to change."""
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/python-modules/packages/authres.git



More information about the Python-modules-commits mailing list